@@ -30,7 +30,7 @@ class Transport(JSONEncoderUtils):
 
     @property
     def _dashboard_request_url(self):
-        return self.config.get_option("dashboard.dashboard_request_url")[1:-1]
+        return self.config.get_option("dashboard.dashboard_request_url")
 
     @property
     def auth_header(self):
@@ -39,8 +39,8 @@ class Transport(JSONEncoderUtils):
     @property
     def _search_dashboard_url(self):
         return (
-            self.config["dashboard.base_dashboard_url"][1:-1]
-            + self.config["dashboard.search_dashboard_endpoint"][1:-1]
+            self.config["dashboard.base_dashboard_url"]
+            + self.config["dashboard.search_dashboard_endpoint"]
         )
 
     @staticmethod
@@ -67,18 +67,24 @@ class Transport(JSONEncoderUtils):
         # Needs to be a supported dashboard type
         if dashboard_type not in self.DASHBOARD_TYPES:
             return
-        url = self.config.get_option("api.base_url")[:-2]
-        version = self.config.get_option("api.base_url")[-2:]
+        # Get the URL but not the version
+        url = "/".join(self.config.get_option("api.base_url").split("/")[:-1]) + "/"
+        # Split off the version separately
+        version = self.config.get_option("api.base_url").split("/")[-1]
+        # Parse the endpoint so it becomes 'endpoint/schema' instead of '/endpoint/schema'
+        if endpoint.startswith("/"):
+            endpoint = endpoint[1:]
         request_body = {
             dashboard_type: {
                 "body": parameters,
                 "url": url,
                 "version": version,
-                "endpoint": endpoint[1:],
+                "endpoint": endpoint,
                 "metadata": parameters,
                 "query": parameters.get("query"),
             },
         }
+        self.logger.debug(request_body)
         req = Request(
             method=method.upper(),
             url=self._dashboard_request_url,
@@ -91,7 +97,7 @@ class Transport(JSONEncoderUtils):
 
         if verbose:
             dashboard_url = (
-                self.config["dashboard.base_dashboard_url"][1:-1]
+                self.config["dashboard.base_dashboard_url"]
                 + DASHBOARD_MAPPINGS[dashboard_type]
             )
             self.print_dashboard_url(dashboard_url)
@@ -125,8 +131,13 @@ class Transport(JSONEncoderUtils):
             dashboard_type="multivector_search",
         )
 
+    def print_dashboard_message(self, message: str):
+        if self.config["dashboard.show_dashboard_link"]:
+            print(message)
+
     def print_dashboard_url(self, dashboard_url):
-        print(f"You can now visit the dashboard at {dashboard_url}")
+        if self.config["dashboard.show_dashboard_link"]:
+            print(f"You can now visit the dashboard at {dashboard_url}")
 
     def make_http_request(
         self,
