@@ -40,11 +40,29 @@ class Utils(APIClient, _Base, DocUtils):
         else:
             raise ValueError(f"{label_name} is not in the {dataset_id} schema")
 
-    def _remove_empty_vector_fields(self, docs, vector_field: str) -> List[Dict]:
+    def _remove_empty_vector_fields(self, documents, vector_field: str) -> List[Dict]:
         """
         Remove documents with empty vector fields
         """
-        return [d for d in docs if d.get(vector_field)]
+        return [d for d in documents if d.get(vector_field)]
 
-    def _convert_id_to_string(self, docs):
-        self.set_field_across_documents("_id", [str(i["_id"]) for i in docs], docs)
+    def _convert_id_to_string(self, documents):
+        self.set_field_across_documents(
+            "_id", [str(i["_id"]) for i in documents], documents
+        )
+
+    def _are_fields_in_schema(self, fields, dataset_id, schema=None):
+        """
+        Check fields are in schema
+        """
+        if schema is None:
+            schema = self.datasets.schema(dataset_id)
+        invalid_fields = []
+        for i in fields:
+            if i not in schema:
+                invalid_fields.append(i)
+        if len(invalid_fields) > 0:
+            raise ValueError(
+                f"{', '.join(invalid_fields)} are invalid fields. They are not in the dataset schema."
+            )
+        return
