@@ -11,7 +11,6 @@ from relevanceai.base import _Base
 from relevanceai.api.client import BatchAPIClient
 from typeguard import typechecked
 from dataclasses import dataclass
-import plotly.graph_objs as go
 import numpy as np
 import pandas as pd
 
@@ -126,7 +125,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
             Marker size of the plot
         """
 
-        docs = self._get_plot_docs(
+        documents = self._get_plot_documents(
             dataset_id=dataset_id,
             vector_field=vector_field,
             number_of_points_to_render=number_of_points_to_render,
@@ -134,8 +133,8 @@ class Projector(BatchAPIClient, _Base, DocUtils):
             hover_label=hover_label,
         )
 
-        return self.plot_from_docs(
-            docs,
+        return self.plot_from_documents(
+            documents,
             vector_field=vector_field,
             vector_label=vector_label,
             label_char_length=label_char_length,
@@ -244,7 +243,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
                 "You are missing Jupyter Dash, please run `pip install jupyter_dash`"
             )
 
-        docs = self._get_plot_docs(
+        documents = self._get_plot_documents(
             dataset_id=dataset_id,
             vector_field=vector_field,
             number_of_points_to_render=number_of_points_to_render,
@@ -252,8 +251,8 @@ class Projector(BatchAPIClient, _Base, DocUtils):
             hover_label=hover_label,
         )
 
-        return self.plot_from_docs(
-            docs,
+        return self.plot_from_documents(
+            documents,
             vector_field=vector_field,
             vector_label=vector_label,
             label_char_length=label_char_length,
@@ -272,7 +271,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
             interactive=interactive,
         )
 
-    def _get_plot_docs(
+    def _get_plot_documents(
         self,
         dataset_id: str,
         vector_field: str,
@@ -295,18 +294,18 @@ class Projector(BatchAPIClient, _Base, DocUtils):
         # Check hover label field
         [self._is_valid_label_name(dataset_id, label) for label in hover_label]
 
-        docs = self.get_documents(
+        documents = self.get_documents(
             dataset_id,
             number_of_documents=number_of_points_to_render,
             batch_size=1000,
             select_fields=["_id", vector_field] + vector_label_field + hover_label,
         )
-        docs = self._remove_empty_vector_fields(docs, vector_field)
-        return docs
+        documents = self._remove_empty_vector_fields(documents, vector_field)
+        return documents
 
-    def plot_from_docs(
+    def plot_from_documents(
         self,
-        docs: List[Dict],
+        documents: List[Dict],
         vector_field: str,
         # Plot rendering args
         vector_label: Union[None, str] = None,
@@ -328,16 +327,22 @@ class Projector(BatchAPIClient, _Base, DocUtils):
         jupyter_dash=False,
         interactive: bool = True,
     ):
+
+        import plotly.graph_objects as go
+
         # Adjust vector label
         if show_image is False and vector_label:
             self.set_field_across_documents(
                 vector_label,
-                [i[vector_label][:label_char_length] + "..." for i in docs],
-                docs,
+                [i[vector_label][:label_char_length] + "..." for i in documents],
+                documents,
             )
 
+        if vector_label:
+            point_labels = self.get_field_across_documents(vector_label, documents)
+
         # Dimension reduce vectors
-        vectors = np.array(self.get_field_across_documents(vector_field, docs))
+        vectors = np.array(self.get_field_across_documents(vector_field, documents))
         vectors_dr = DimReduction.dim_reduce(
             vectors=vectors, dr=dr, dr_args=dr_args, dims=dims
         )
@@ -346,7 +351,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
             points["z"] = vectors_dr[:, 2]
 
         embedding_df = pd.DataFrame(points)
-        embedding_df = pd.concat([embedding_df, pd.DataFrame(docs)], axis=1)
+        embedding_df = pd.concat([embedding_df, pd.DataFrame(documents)], axis=1)
 
         # Set hover labels
         if vector_label:
@@ -389,6 +394,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
             marker_size=marker_size,
             cluster=cluster,
             label_char_length=label_char_length,
+            vector_label=point_labels,
         )
 
         layout = self._generate_layout(plot_title=plot_title)
@@ -402,7 +408,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
                 plot_data=plot_data,
                 layout=layout,
                 show_image=show_image,
-                docs=docs,
+                documents=documents,
                 vector_label=vector_label,
                 vector_field=vector_field,
                 interactive=interactive,
@@ -410,8 +416,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
 
         else:
             fig = go.Figure(data=plot_data, layout=layout)
-            fig.show()
-        return
+            return fig
 
     def _generate_plot_data(
         self,
@@ -427,6 +432,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
             None,
         ],
         label_char_length: int,
+        vector_label: str,
     ):
         """ """
 
@@ -441,6 +447,7 @@ class Projector(BatchAPIClient, _Base, DocUtils):
                         dims=dims,
                         marker_size=marker_size,
                         label_char_length=label_char_length,
+                        vector_label=vector_label,
                     )
                 )
 
@@ -453,18 +460,21 @@ class Projector(BatchAPIClient, _Base, DocUtils):
                     dims=dims,
                     marker_size=marker_size,
                     label_char_length=label_char_length,
+                    vector_label=vector_label,
                 )
             )
 
         return data
 
     def _generate_layout(self, plot_title):
+        import plotly.graph_objects as go
 
         axes_3d = {
             "title": "",
             "backgroundcolor": "#ffffff",
             "showgrid": False,
             "showticklabels": False,
+            "showbackground": False,
         }
 
         axes_2d = {"title": "", "visible": False, "showticklabels": False}
@@ -488,8 +498,15 @@ class Projector(BatchAPIClient, _Base, DocUtils):
         return layout
 
     def _generate_plot_info(
-        self, embedding_df, hover_label, dims, marker_size, label_char_length
+        self,
+        embedding_df,
+        hover_label,
+        dims,
+        marker_size,
+        label_char_length,
+        vector_label,
     ):
+        import plotly.graph_objects as go
 
         custom_data, hovertemplate = self._generate_hover_template(
             df=embedding_df,
@@ -502,10 +519,11 @@ class Projector(BatchAPIClient, _Base, DocUtils):
             "x": embedding_df["x"],
             "y": embedding_df["y"],
             "showlegend": False,
-            "mode": "markers",
+            "mode": "markers+text",
             "marker": {"size": marker_size, "symbol": "circle", "opacity": 0.75},
             "customdata": custom_data,
             "hovertemplate": hovertemplate,
+            "text": vector_label,
         }
 
         if dims == 2:
