@@ -1,4 +1,4 @@
-from relevanceai.http_client import Client, Dataset, Clusterer
+from relevanceai.http_client import Client, Dataset, ClusterOps
 
 
 def test_dataset_api_kmeans_centroids_properties(
@@ -12,8 +12,8 @@ def test_dataset_api_kmeans_centroids_properties(
 
     model = KMeansModel()
 
-    clusterer: Clusterer = test_client.Clusterer(model=model, alias=alias)
-    clusterer.fit(dataset=test_dataset_df, vector_fields=[vector_field])
+    clusterer: ClusterOps = test_client.ClusterOps(model=model, alias=alias)
+    clusterer.fit_predict_update(dataset=test_dataset_df, vector_fields=[vector_field])
 
     assert f"_cluster_.{vector_field}.{alias}" in test_dataset_df.schema
 
