@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 """
 Test the clustering workflow from getting the documents, clustering and then inserting the relevant centroids
 """
@@ -7,7 +8,7 @@ import pytest
 from relevanceai import Client
 from relevanceai.dataset_api import Dataset
 
-from relevanceai.clusterer import Clusterer
+from relevanceai.clusterer import ClusterOps
 from relevanceai.clusterer import CentroidClusterBase
 
 
@@ -21,7 +22,7 @@ def test_dataset_api_kmeans_integration(test_client: Client, test_dataset_df: Da
         def __init__(self, model):
             self.model: KMeans = model
 
-        def fit_transform(self, vectors):
+        def fit_predict(self, vectors):
             return self.model.fit_predict(vectors)
 
         def get_centers(self):
@@ -29,8 +30,8 @@ def test_dataset_api_kmeans_integration(test_client: Client, test_dataset_df: Da
 
     model = KMeansModel(model=KMeans())
 
-    clusterer = test_client.Clusterer(model=model, alias=alias)
+    clusterer = test_client.ClusterOps(model=model, alias=alias)
 
-    clusterer.fit(dataset=test_dataset_df, vector_fields=[vector_field])
+    clusterer.fit_predict_update(dataset=test_dataset_df, vector_fields=[vector_field])
 
     assert f"_cluster_.{vector_field}.{alias}" in test_dataset_df.schema
